@@ -23,9 +23,8 @@
 Dialog box for project settings
 """
 
-import gobject
 import gtk
-from glade import GladeWindow
+from pitivi.ui.glade import GladeWindow
 
 class ProjectSettingsDialog(GladeWindow):
     glade_file = "projectsettings.glade"
@@ -40,12 +39,12 @@ class ProjectSettingsDialog(GladeWindow):
         w = self.widgets
         w["nameentry"].set_text(self.project.name)
         w["descriptiontextview"].get_buffer().set_text(self.project.description)
-        
+
 
     def updateSettings(self):
         # apply selected settings to project
         w = self.widgets
-        
+
         # Name/Description
         self.project.name = w["nameentry"].get_text()
         txtbuffer = w["descriptiontextview"].get_buffer()
